Capabilities

Struct Capabilities 

pub struct Capabilities {
    pub key_usage: KeyUsages,
    pub basic_constraints: BasicConstraints,
}
An abstraction over X.509 Extensions and PKCS#10 Attributes, representing the capabilities of a certificate. Capabilities can be converted from and to both Attributes and Extensions.

This struct only covers the Attributes/Extensions currently relevant to polyproto.

Fields

key_usage: KeyUsages

The key usage extension defines the purpose of the key contained in the certificate.

basic_constraints: BasicConstraints

Extension type that defines whether a given certificate is allowed to sign additional certificates and what path length restrictions may exist.

Implementations

Source

impl Capabilities

pub fn default_actor() -> Self

Sane default for actor ID-CSR/ID-Cert Capabilities. Uses the DigitalSignature flag, not the ContentCommitment flag.

pub fn default_home_server() -> Self

Sane default for home server ID-CSR/ID-Cert Capabilities.

pub fn validate(&self) -> Result<(), ConstraintError>

Validates that these capabilities are well-formed according to X.509 and polyproto constraints. This validation is target-independent.

Errors

Returns a crate::errors::ConstraintError if the capabilities are malformed.

pub fn validate_for_actor(&self) -> Result<(), ConstraintError>

Validates that these capabilities are correct for an actor certificate.

In addition to the base validation, this checks:

  • The CA flag must be false
  • Must have DigitalSignature or ContentCommitment
  • Must not have KeyCertSign
Errors

Returns a crate::errors::ConstraintError if the capabilities are not valid for an actor.

pub fn validate_for_home_server(&self) -> Result<(), ConstraintError>

Validates that these capabilities are correct for a home server certificate.

In addition to the base validation, this checks:

  • The CA flag must be true
  • Must have KeyCertSign
Errors

Returns a crate::errors::ConstraintError if the capabilities are not valid for a home server.