IdCsrInner

Struct IdCsrInner 

pub struct IdCsrInner<S: Signature, P: PublicKey<S>> {
    pub version: PkcsVersion,
    pub subject: PolyprotoDistinguishedName,
    pub subject_public_key: P,
    pub capabilities: Capabilities,
    /* private fields */
}
In the context of PKCS #10, this is a CertificationRequestInfo:

CertificationRequestInfo ::= SEQUENCE {
    version       INTEGER { v1(0) } (v1,...),
    subject       Name,
    subjectPKInfo SubjectPublicKeyInfo{{ PKInfoAlgorithms }},
    attributes    [0] Attributes{{ CRIAttributes }}
}

Fields

version: PkcsVersion

PKCS#10 version. Default: 0 for PKCS#10 v1

subject: PolyprotoDistinguishedName

Information about the subject (actor).

subject_public_key: P

The subjects’ public key: PublicKey.

capabilities: Capabilities

Capabilities requested by the subject.

Implementations

Source

impl<S: Signature, P: PublicKey<S>> IdCsrInner<S, P>

pub fn new( subject: &PolyprotoDistinguishedName, public_key: &P, capabilities: &Capabilities, ) -> Result<IdCsrInner<S, P>, CertificateConversionError>

Creates a new IdCsrInner.

Errors

This method returns an error if the resulting IdCsrInner does not pass validation.

pub fn from_der_unchecked( bytes: &[u8], ) -> Result<Self, CertificateConversionError>

Create an unchecked IdCsrInner from a byte slice containing a DER encoded PKCS #10 CSR.

Errors

This method returns an error if:

  • The byte slice does not contain a valid DER encoded X.509 certification request info.
  • The certification request info cannot be converted to a polyproto IdCsrInner.
pub fn to_der(self) -> Result<Vec<u8>, CertificateConversionError>

Encode this type as DER, returning a byte vector.

Errors

This method returns an error if the inner CSR cannot be converted to the underlying X.509 type or if the DER encoding fails.