pub struct EncryptedPkm {
pub serial_number: SerialNumber,
pub key_data: PrivateKeyInfo,
pub encryption_algorithm: AlgorithmIdentifierOwned,
}Expand description
A private key material structure for storing encrypted private key material on a home server.
For more information, such as how this type is represented in JSON, see the
type definition of EncryptedPKM on the polyproto documentation website
Fields
serial_number: SerialNumberThe serial number of the certificate that this private key material is associated with.
key_data: PrivateKeyInfoThe encrypted private key material, along with the signature algorithm of the private key.
encryption_algorithm: AlgorithmIdentifierOwnedThe encryption algorithm used to encrypt the private key material.