pub struct FederationId { /* private fields */ }Expand description
A FederationId is a globally unique identifier for an actor in the context
of polyproto.
Implementations
Sourceimpl FederationId
impl FederationId
Sourcepub fn new(id: &str) -> Result<Self, ConstraintError>
pub fn new(id: &str) -> Result<Self, ConstraintError>
Validates input, then creates a new FederationId.
Errors
This method returns a ConstraintError if the provided ID does not match the polyproto federation ID format.
Panics
This method will panic if the internal regular expression for federation IDs fails to compile.