pub struct IdCsrInner<S: Signature, P: PublicKey<S>> {
pub version: PkcsVersion,
pub subject: PolyprotoDistinguishedName,
pub subject_public_key: P,
pub capabilities: Capabilities,
/* private fields */
}Expand description
In the context of PKCS #10, this is a CertificationRequestInfo:
CertificationRequestInfo ::= SEQUENCE {
version INTEGER { v1(0) } (v1,...),
subject Name,
subjectPKInfo SubjectPublicKeyInfo{{ PKInfoAlgorithms }},
attributes [0] Attributes{{ CRIAttributes }}
}Fields
version: PkcsVersionPKCS#10 version. Default: 0 for PKCS#10 v1
subject: PolyprotoDistinguishedNameInformation about the subject (actor).
subject_public_key: PThe subjects’ public key: PublicKey.
capabilities: CapabilitiesCapabilities requested by the subject.
Implementations
Sourceimpl<S: Signature, P: PublicKey<S>> IdCsrInner<S, P>
impl<S: Signature, P: PublicKey<S>> IdCsrInner<S, P>
Sourcepub fn new(
subject: &PolyprotoDistinguishedName,
public_key: &P,
capabilities: &Capabilities,
) -> Result<IdCsrInner<S, P>, CertificateConversionError>
pub fn new( subject: &PolyprotoDistinguishedName, public_key: &P, capabilities: &Capabilities, ) -> Result<IdCsrInner<S, P>, CertificateConversionError>
Creates a new IdCsrInner.
Errors
This method returns an error if the resulting IdCsrInner does not pass
validation.
Sourcepub fn from_der_unchecked(
bytes: &[u8],
) -> Result<Self, CertificateConversionError>
pub fn from_der_unchecked( bytes: &[u8], ) -> Result<Self, CertificateConversionError>
Create an unchecked IdCsrInner from a byte slice containing a DER encoded PKCS #10 CSR.
Errors
This method returns an error if:
- The byte slice does not contain a valid DER encoded X.509 certification request info.
- The certification request info cannot be converted to a polyproto
IdCsrInner.